---
title: <span class="badge builder"></span> BackgroundConfig
---
# <span class="badge builder"></span> BackgroundConfig

## Constructor

```python
BackgroundConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> canvas.BackgroundConfig
```

### <span class="badge object-method"></span> color

```python
def color(color: cogbuilder.Builder[common.ColorDimensionConfig]) -> typing.Self
```

### <span class="badge object-method"></span> image

```python
def image(image: cogbuilder.Builder[common.ResourceDimensionConfig]) -> typing.Self
```

### <span class="badge object-method"></span> size

```python
def size(size: canvas.BackgroundImageSize) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [BackgroundConfig](./object-BackgroundConfig.md)
